"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aws_log_1 = require("aws-log");
const aws_orchestrate_1 = require("aws-orchestrate");
const shared_1 = require("../../shared");
const shared_2 = require("./shared");
const date_fns_1 = require("date-fns");
exports.config = {
    description: `Receives a list of deployments which are then converted to a Discord message and sent`
};
const fn = async (request, context) => {
    const { log, sequence, apiGateway } = context;
    if (!request.data) {
        log.error(`This fn requires the "data" property but none was provided!`, {
            request
        });
        throw new Error("No Data Property Found");
    }
    const branch = request.branch;
    const limit = request.limit || 5;
    const filteredData = request.data
        .filter(i => !branch || i.branch === branch)
        .map(shared_1.whitelist("site_id", "build_id", "name", "branch", "committer", "title", "state", "updated_at", "deploy_ssl_url", "deploy_time", "updated_at"))
        .sort((a, b) => {
        if (a.updated_at > b.updated_at) {
            return -1;
        }
        else if (a.updated_at < b.updated_at) {
            return 1;
        }
        return 0;
    })
        .slice(0, limit);
    log.info(`Building Discord message of deploys on branch "${branch}"`, Object.assign({ branch, dataRecords: request.data.length, filteredRecords: filteredData.length, filteredData, sequence: JSON.stringify(sequence) }, shared_1.reducedGateway(apiGateway)));
    const message = {
        content: `The **${branch}** has the following recent commits:`,
        embeds: filteredData.map(i => {
            return {
                color: i.state === "error" ? 0xff0000 : 0x3cb371,
                description: `${i.committer} commited at ${date_fns_1.format(i.updated_at, "MMM Do")} _at_ ${date_fns_1.format(i.updated_at, "hh:mm a Z")}`,
                author: {
                    name: i.title,
                    icon_url: i.state === "error"
                        ? "https://img.icons8.com/office/40/000000/error.png"
                        : "https://img.icons8.com/office/40/000000/ok.png"
                }
            };
        })
    };
    await shared_2.sendToDiscord(shared_2.getDiscordWebhookUrl("netlify"), message);
    const payload = {
        sequence,
        branch,
        limit,
        data: filteredData
    };
    log.debug(`invoking next function`, { sequence: sequence.toJSON() });
    await aws_log_1.invoke(...sequence.next(payload));
    log.debug("invocation of next() is complete", {
        sequence: sequence.toJSON()
    });
    return payload;
};
exports.handler = aws_orchestrate_1.wrapper(fn);
