"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const shared_1 = require("./shared");
const aws_orchestrate_1 = require("aws-orchestrate");
exports.config = {
    description: `Accepts webhook messages from Netlify involving build errors and sends them to Discord.`,
    events: [
        {
            http: {
                method: "post",
                path: "/notify/build-error",
                cors: true
            }
        }
    ]
};
const fn = async (request, context) => {
    const { log, apiGateway } = context;
    log.info(`Build error detected in ${request.repo}, branch ${request.branch}`, { request });
    await shared_1.sendToDiscord(shared_1.getDiscordWebhookUrl("netlify"), {
        content: `Build error in the "${request.branch}" branch of **${request.repo}**!`,
        embeds: [
            {
                color: 0xff0000,
                thumbnail: {
                    url: "https://img.icons8.com/office/80/000000/error.png",
                    height: 80,
                    width: 80
                },
                fields: [
                    {
                        name: "Host",
                        value: request.hostname
                    },
                    {
                        name: "Commit",
                        value: request.commit
                    },
                    {
                        name: "Error Text",
                        value: request.errorText
                    },
                    {
                        name: "Stack Trace",
                        value: request.stack
                    }
                ]
            }
        ]
    });
};
exports.handler = aws_orchestrate_1.wrapper(fn);
