"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aws_log_1 = require("aws-log");
const aws_orchestrate_1 = require("aws-orchestrate");
const reducedGateway_1 = require("../../shared/reducedGateway");
const shared_1 = require("./shared");
const createMessage_1 = require("./netlifyEndState/createMessage");
exports.config = {
    description: `Sends a notification to Discord about having reached a final state (aka, error or success)`
};
const fn = async (request, context) => {
    const { log, sequence, apiGateway } = context;
    if (!request.data) {
        log.error(`This fn requires the "data" property but none was provided!`, {
            request
        });
        throw new Error("No Data Property Found");
    }
    log.info(`Netlify deployment of the ${request.data.branch} branch of ${request.data.name} repo ${request.data.state === "error" ? "failed" : "succeeded"}.`, Object.assign({ repo: request.data.name, branch: request.data.branch, fullRequest: request.data, sequence: sequence.toJSON() }, reducedGateway_1.reducedGateway(apiGateway)));
    await shared_1.sendToDiscord(shared_1.getDiscordWebhookUrl("netlify"), createMessage_1.createMessage(request.data));
    if (!sequence.isDone) {
        log.debug(`invoking next function`, { sequence: sequence.toJSON() });
        await aws_log_1.invoke(...sequence.next(request.data));
        log.debug("invocation of next() is complete", {
            sequence: sequence.toJSON()
        });
    }
    else if (sequence.isSequence) {
        log.info("Sequence has completed", { sequence: sequence.toJSON() });
    }
};
exports.handler = aws_orchestrate_1.wrapper(fn);
