"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const date_fns_1 = require("date-fns");
const aws_log_1 = require("aws-log");
const lookups_1 = require("./lookups");
function createMessage(netlifyEvent) {
    const info = {
        repo: netlifyEvent.name,
        branch: netlifyEvent.branch,
        state: netlifyEvent.state,
        errorMessage: netlifyEvent.error_message,
        buildId: netlifyEvent.build_id,
        siteId: netlifyEvent.site_id,
        userId: netlifyEvent.user_id,
        commitUrl: netlifyEvent.deploy_ssl_url,
        prodUrl: netlifyEvent.ssl_url,
        branchUrl: netlifyEvent.ssl_url.replace('https://', `https://${netlifyEvent.branch}--`),
        committer: netlifyEvent.committer,
        when: date_fns_1.format(netlifyEvent.created_at, 'h:mm a  ZZZZ'),
    };
    const context = aws_log_1.logger()
        .reloadContext()
        .getContext();
    return netlifyEvent.state === 'error'
        ? {
            content: `Netlify failed to publish **${info.repo}** @ **${info.branch}**`,
            embeds: [
                {
                    title: `Deploy Failure`,
                    color: 0xff0000,
                    description: `Build "${info.buildId}" failed with the error: "_${info.errorMessage}_"`,
                    thumbnail: {
                        url: lookups_1.repoThumbnail(info.repo),
                        height: 75,
                        width: 75,
                    },
                    author: {
                        icon_url: 'https://img.icons8.com/office/40/000000/error.png',
                        name: netlifyEvent.title ? netlifyEvent.title : `${info.repo} @ ${info.branch} # ${info.buildId}`,
                    },
                    fields: [
                        {
                            name: 'AWS Request ID',
                            value: `[${context.awsRequestId}](https://us-west-2.console.aws.amazon.com/cloudwatch/home?region=${context.awsRegion}#logStream:group=${context.logGroupName}) in _${context.awsRegion}_`,
                        },
                        {
                            name: 'Logger Correlation ID',
                            value: `[${aws_log_1.logger().getCorrelationId()}](https://app.logz.io/#dashboard/kibana)`,
                        },
                        {
                            name: 'Changes in this Commit',
                            value: `[Changes in ${netlifyEvent.commit_ref}](${netlifyEvent.commit_url})`,
                        },
                    ],
                },
            ],
        }
        : {
            content: `Netlify deployed successfully for **${info.repo}** @ **${info.branch}**`,
            embeds: [
                {
                    title: `Deploy Success`,
                    color: 0x3cb371,
                    description: `Netlify successfully published commit "${info.buildId}" on branch "${info.branch}"`,
                    url: info.commitUrl,
                    thumbnail: {
                        url: lookups_1.repoThumbnail(info.repo),
                        height: 75,
                        width: 75,
                    },
                    author: {
                        icon_url: 'https://img.icons8.com/office/40/000000/ok.png',
                        name: netlifyEvent.title ? netlifyEvent.title : `${info.repo} @ ${info.branch} # ${info.buildId}`,
                    },
                    fields: [
                        {
                            name: 'Branch Site',
                            value: info.branchUrl,
                        },
                        {
                            name: 'Commit Site',
                            value: info.commitUrl,
                        },
                        {
                            name: 'Production Site',
                            value: info.prodUrl,
                        },
                        {
                            name: 'Changes in this Commit',
                            value: `[Changes in ${netlifyEvent.commit_ref}](${netlifyEvent.commit_url})`,
                        },
                    ],
                },
            ],
        };
}
exports.createMessage = createMessage;
