"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const aws_log_1 = require("aws-log");
function getDiscordWebhookUrl(siteId) {
    const knownWebhooks = {
        netlify: 'https://discordapp.com/api/webhooks/565199014723846145/dsTKCaVHGDjI8samMH310nxaonJTSEcvIxPrsWvUkdbB6Ac4hP81y4sP-C63hChaL8sb',
    };
    return knownWebhooks[siteId] ? knownWebhooks[siteId] : '';
}
exports.getDiscordWebhookUrl = getDiscordWebhookUrl;
async function sendToDiscord(url, data) {
    const log = aws_log_1.logger().reloadContext();
    try {
        const response = await axios_1.default({
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
                'User-Agent': 'DiscordBot',
            },
            data,
        });
        if (response.status >= 300) {
            const msg = `There was an error attempt to send message to Discord at: ${url}. The status code returned was ${response.status}/${response.statusText}`;
            log.error(msg);
            throw new Error(msg);
        }
        log.info('Call to Discord webhook was successful', {
            url,
            status: response.status,
            data: response.data,
        });
    }
    catch (e) {
        const message = `There was a problem sending a message to the Discord webhook at ${url}. The error was: ${e.message}`;
        log.error(message, { isDiscordMessage: true, discordUrl: url, failurePoint: 'axios send' });
        throw e;
    }
}
exports.sendToDiscord = sendToDiscord;
