"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const shared_1 = require("./shared");
const axios_1 = __importDefault(require("axios"));
const aws_orchestrate_1 = require("aws-orchestrate");
const getNetlifySecrets_1 = require("../../shared/getNetlifySecrets");
exports.config = {
    description: `Get's a list of a site's deployments using Netlify's API`
};
exports.fn = async (request, context) => {
    const { log, sequence, apiGateway } = context;
    log.info(`Received request for Netlify's site deployments`, {
        request,
        sequence: sequence.toJSON(),
        apiGateway
    });
    const accessToken = await getNetlifySecrets_1.getAccessToken(request);
    const siteId = await getNetlifySecrets_1.getSiteId(request);
    const NETLIFY_URL = `${shared_1.NETLIFY_BASE_URL}/${siteId}/deploys`;
    const NETLIFY_URL_WITH_TOKEN = NETLIFY_URL + `?access_token=${accessToken}`;
    log.info(`Making call to Netlify`, { apiGateway, NETLIFY_URL });
    const results = await axios_1.default.get(NETLIFY_URL_WITH_TOKEN, {
        headers: {
            "Content-Type": "application/json"
        }
    });
    log.info("Axios has returned from Netlify with results", {
        status: results.status,
        statusText: results.statusText,
        records: results.data.length
    });
    return { data: results.data };
};
exports.handler = aws_orchestrate_1.wrapper(exports.fn);
