"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aws_orchestrate_1 = require("aws-orchestrate");
const getNetlifySecrets_1 = require("../../shared/getNetlifySecrets");
const shared_1 = require("../discord/shared");
const reducedGateway_1 = require("../../shared/reducedGateway");
exports.config = {
    description: "Receives Netlify Deploy webhooks and then orchestrates a response to Discord",
    memorySize: 1024,
    events: [
        {
            http: {
                method: "post",
                path: "notify/deploy"
            }
        }
    ]
};
const fn = async (request, context) => {
    const { log, apiGateway } = context;
    log.info(`Netlify webhook received for ${request.branch} in state "${request.state}" [ ${request.name} ]`, Object.assign({ request }, reducedGateway_1.reducedGateway(apiGateway)));
    const isFinalState = request.state === "error" || request.state === "ready";
    const accessToken = await getNetlifySecrets_1.getAccessToken(request);
    const siteId = request.site_id;
    const webhook = shared_1.getDiscordWebhookUrl("netlify");
    const sequence = isFinalState
        ?
            aws_orchestrate_1.LambdaSequence.add("discordNetlifyEndState", { data: request })
                .add("netlifyDeploymentList", { accessToken, siteId })
                .add("msgNetlifyList", { data: ":data", branch: request.branch })
        :
            aws_orchestrate_1.LambdaSequence.add("discordNetlifyKickoff", { data: request })
                .add("netlifyDeployedBranches", {
                accessToken,
                filter: { branch: request.branch }
            })
                .add("discordNetlifyBranches", { webhook });
    return { sequence, data: request };
};
exports.handler = aws_orchestrate_1.wrapper(fn);
