"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const aws_orchestrate_1 = require("aws-orchestrate");
const axios_1 = __importDefault(require("axios"));
const shared_1 = require("./shared");
const getNetlifySecrets_1 = require("../../shared/getNetlifySecrets");
exports.config = {
    description: `Get's a list of a site's deployments using Netlify's API`
};
exports.fn = async (request, context) => {
    const { log, sequence, apiGateway } = context;
    log.info(`Received request for Netlify's branch deployments`, {
        request,
        sequence: sequence.toJSON(),
        apiGateway
    });
    const accessToken = await getNetlifySecrets_1.getAccessToken(request);
    log.debug("About to make request to netlify");
    const response = await axios_1.default.get(shared_1.NETLIFY_BASE_URL + `?access_token=${accessToken}`, {
        headers: {
            "Content-Type": "application/json"
        }
    });
    log.debug("Back from netlify", { response });
    if (response.statusText !== "OK") {
        throw new Error(`Problem getting Netlify request [ $${response.status} ]: ${response.statusText}`);
    }
    const data = response.data;
    return { data };
};
exports.handler = aws_orchestrate_1.wrapper(exports.fn);
