"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const aws_ssm_1 = require("aws-ssm");
const axios_1 = __importDefault(require("axios"));
const path_1 = __importDefault(require("path"));
const aws_log_1 = require("aws-log");
let _secrets;
const getSecrets = async () => {
    if (!_secrets) {
        const ssm = new aws_ssm_1.SSM();
        _secrets = await ssm.modules(["discord"]);
    }
    return _secrets;
};
exports.NETLIFY_BASE_URL = "https://api.netlify.com/api/v1/sites/";
async function netlifyApi(endpoint) {
    const log = aws_log_1.logger().reloadContext();
    try {
        const url = path_1.default.join(exports.NETLIFY_BASE_URL, endpoint);
        const access_token = (await getSecrets()).netlify.TOKEN;
        log.debug(`Making request to ${url} to retrieve netlify content`);
        const response = await axios_1.default.get(url, {
            headers: {
                "Content-Type": "application/json"
            },
            params: {
                access_token
            }
        });
        if (response.statusText === "OK") {
            return response.data;
        }
        else {
            const msg = `Problem getting data from the endpoint [ ${url} ]. Error code was ${response.status}`;
            throw new Error(msg);
        }
    }
    catch (e) {
        log.error(e);
        throw e;
    }
}
exports.netlifyApi = netlifyApi;
