export interface INetlifyDeployHook {
    height: number;
    width: number;
    uom: 'inch' | 'cm' | 'mm';
}
export interface IDiscordHook {
    statusCode: 200 | 202;
}
export interface IDiscordMessageFormat {
    content: string;
    embeds?: IDiscordMessageEmbeds[];
}
export interface IDiscordMessageEmbeds {
    title?: string;
    type?: 'rich' | string;
    description?: string;
    url?: string;
    color?: number;
    footer?: IDiscordMessageEmbedFooter;
    image?: IDiscordMessageEmbedImage;
    thumbnail?: IDiscordMessageEmbedThumbnail;
    video?: IDiscordMessageEmbedVideo;
    provider?: IDiscordMessageEmbedProvider;
    author?: IDiscordMessageEmbedAuthor;
    fields?: IDiscordMessageEmbedField[];
}
export interface IDiscordMessageEmbedFooter {
    text: string;
    icon_url?: string;
    proxy_icon_url?: string;
}
export interface IDiscordMessageEmbedImage {
    url?: string;
    proxy_url?: string;
    height?: number;
    width?: number;
}
export interface IDiscordMessageEmbedAuthor {
    name?: string;
    url?: string;
    icon_url?: string;
    proxy_icon_url?: string;
}
export interface IDiscordMessageEmbedProvider {
    name?: string;
    url?: string;
}
export interface IDiscordMessageEmbedThumbnail {
    url?: string;
    proxy_url?: string;
    height?: number;
    width?: number;
}
export interface IDiscordMessageEmbedVideo {
    url?: string;
    height?: number;
    width?: number;
}
export interface IDiscordMessageEmbedField {
    name: string;
    value: string;
    inline?: boolean;
}
export interface INetlifyDeploy {
    message: string;
    id: string;
    site_id: string;
    build_id: string;
    state: 'error' | 'ready';
    name: string;
    url: string;
    ssl_url: string;
    admin_url: string;
    deploy_url: string;
    deploy_ssl_url: string;
    created_at: string;
    updated_at: string;
    user_id: string;
    error_message: string;
    required: any[];
    required_functions: null | any[];
    commit_ref: null | string;
    review_id: null | string;
    branch: 'develop' | 'stage' | 'production';
    commit_url: null | string;
    skipped: null | string;
    locked: null | string;
    log_access_attributes: {
        type: 'firebase';
        url: string;
    };
    title: null | string;
    review_url: null | string;
    published_at: null | string;
    deploy_time: null | string;
    available_functions: any[];
    summary: {
        status: string;
        messages: string[];
    };
    screenshot_url: null | string;
    site_capabilities: {
        title: string;
        asset_acceleration: boolean;
        form_processing: boolean;
        cdn_propagation: 'partial';
        build_gc_exchange: string;
        build_node_pool: string;
        build_cluster: string;
        domain_aliases: boolean;
        secure_site: boolean;
        prerendering: boolean;
        proxying: boolean;
        ssl: string;
        rate_cents: number;
        yearly_rate_cents: number;
        cdn_network: string;
        ipv6_domain: string;
        branch_deploy: boolean;
        managed_dns: boolean;
        geo_ip: boolean;
        split_testing: boolean;
        id: string;
    };
    committer: null | string;
    skipped_log: null | string;
    _context: string;
}
export interface INetlifyDeploySite {
    id: string;
    state: string;
    plan: string;
    name: string;
    custom_domain: string;
    password: string;
    notification_email: string;
    url: string;
    ssl_url: string;
    admin_url: string;
    screenshot_url: string;
    created_at: string;
    updated_at: string;
    user_id: string;
    session_id: string;
    ssl: boolean;
    force_ssl: boolean;
    managed_dns: boolean;
    deploy_url: string;
    published_deploy?: any;
    account_name: string;
    account_slug: string;
    git_provider: string;
    deploy_hook: string;
}
export interface INetlifyDeployListItem {
    id: string;
    branch: string;
    committer: string;
    site_id: string;
    user_id: string;
    build_id: string;
    state: string;
    name: string;
    title: string;
    url: string;
    ssl_url: string;
    updated_at: string;
    deploy_time: number;
    deploy_ssl_url: string;
}
